#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 clash-lib
version:              1.4.0
visibility:           public
id:                   clash-lib-1.4.0-8jJfqnIkCwN4KW43euY1Ba
key:                  clash-lib-1.4.0-8jJfqnIkCwN4KW43euY1Ba
license:              BSD-2-Clause
copyright:
    Copyright © 2012-2016, University of Twente,
    2016-2019, Myrtle Software Ltd,
    2017-2019, QBayLogic B.V., Google Inc.

maintainer:           QBayLogic B.V. <devops@qbaylogic.com>
author:               The Clash Authors
homepage:             https://clash-lang.org/
synopsis:
    Clash: a functional hardware description language - As a library

description:
    Clash is a functional hardware description language that borrows both its
    syntax and semantics from the functional programming language Haskell. The
    Clash compiler transforms these high-level descriptions to low-level
    synthesizable VHDL, Verilog, or SystemVerilog.

    Features of Clash:

    * Strongly typed, but with a very high degree of type inference, enabling both
    safe and fast prototyping using concise descriptions.

    * Interactive REPL: load your designs in an interpreter and easily test all
    your component without needing to setup a test bench.

    * Higher-order functions, with type inference, result in designs that are
    fully parametric by default.

    * Synchronous sequential circuit design based on streams of values, called
    @Signal@s, lead to natural descriptions of feedback loops.

    * Support for multiple clock domains, with type safe clock domain crossing.


    This package provides:

    * The CoreHW internal language: SystemF + Letrec + Case-decomposition

    * The normalisation process that brings CoreHW in a normal form that can be
    converted to a netlist

    * Blackbox/Primitive Handling


    Front-ends (for: parsing, typecheck, etc.) are provided by separate packages:

    * <https://hackage.haskell.org/package/clash-ghc GHC/Haskell Frontend>

    * <https://github.com/christiaanb/Idris-dev Idris Frontend>


    Prelude library: <https://hackage.haskell.org/package/clash-prelude>

category:             Hardware
abi:                  b0daf683e6f2eff4ac87a4c602292962
exposed:              True
exposed-modules:
    Clash.Annotations.BitRepresentation.ClashLib Clash.Backend
    Clash.Backend.SystemVerilog Clash.Backend.VHDL
    Clash.Backend.Verilog Clash.Core.DataCon Clash.Core.EqSolver
    Clash.Core.Evaluator.Types Clash.Core.FreeVars Clash.Core.Literal
    Clash.Core.Name Clash.Core.PartialEval
    Clash.Core.PartialEval.AsTerm Clash.Core.PartialEval.Monad
    Clash.Core.PartialEval.NormalForm Clash.Core.Pretty
    Clash.Core.Subst Clash.Core.Term Clash.Core.TermInfo
    Clash.Core.TermLiteral Clash.Core.TermLiteral.TH
    Clash.Core.Termination Clash.Core.TyCon Clash.Core.Type
    Clash.Core.TysPrim Clash.Core.Util Clash.Core.Var Clash.Core.VarEnv
    Clash.Debug Clash.Driver Clash.Driver.Manifest Clash.Driver.Types
    Clash.Edalize.Edam Clash.Netlist Clash.Netlist.BlackBox
    Clash.Netlist.BlackBox.Parser Clash.Netlist.BlackBox.Types
    Clash.Netlist.BlackBox.Util Clash.Netlist.Id
    Clash.Netlist.Id.Common Clash.Netlist.Id.Internal
    Clash.Netlist.Id.SystemVerilog Clash.Netlist.Id.VHDL
    Clash.Netlist.Id.Verilog Clash.Netlist.Types Clash.Netlist.Util
    Clash.Normalize Clash.Normalize.DEC
    Clash.Normalize.PrimitiveReductions Clash.Normalize.Strategy
    Clash.Normalize.Transformations Clash.Normalize.Types
    Clash.Normalize.Util Clash.Pretty Clash.Primitives.DSL
    Clash.Primitives.GHC.Int Clash.Primitives.GHC.Literal
    Clash.Primitives.GHC.Word Clash.Primitives.Intel.ClockGen
    Clash.Primitives.Sized.ToInteger Clash.Primitives.Sized.Vector
    Clash.Primitives.Types Clash.Primitives.Util
    Clash.Primitives.Verification Clash.Rewrite.Combinators
    Clash.Rewrite.Types Clash.Rewrite.Util Clash.Rewrite.WorkFree
    Clash.Unique Clash.Util Clash.Util.Graph Clash.Util.Interpolate
    Data.Text.Prettyprint.Doc.Extra

hidden-modules:
    Clash.Annotations.TopEntity.Extra Control.Applicative.Extra
    Data.Aeson.Extra Data.List.Extra Data.Map.Ordered.Extra
    Data.Primitive.ByteArray.Extra Data.Semigroup.Monad.Extra
    Data.Set.Ordered.Extra GHC.BasicTypes.Extra GHC.SrcLoc.Extra
    Paths_clash_lib

import-dirs:          /usr/lib/ghc-8.10.4/site-local/clash-lib-1.4.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/clash-lib-1.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/clash-lib-1.4.0
hs-libraries:         HSclash-lib-1.4.0-8jJfqnIkCwN4KW43euY1Ba
depends:
    aeson-1.5.6.0-AbTDFQXjdUODhV2zVRkDXT
    aeson-pretty-0.8.8-1cZuVezWUWzLKBshoIh7qB
    ansi-terminal-0.11-B33URfqMvdcAXWIdsUyVZE array-0.5.4.0
    attoparsec-0.13.2.5-GizkWPNym1tDxXu7xbn7bA base-4.14.1.0
    base16-bytestring-1.0.1.0-LtLEkjBfrnFHc6CuwlPRqd binary-0.8.8.0
    bytestring-0.10.12.0 clash-prelude-1.4.0-1Xz9Cr2u8NVEYRInUZYoYM
    concurrent-supply-0.1.8-IZAedLr6dORBTiHtUESMbz containers-0.6.2.1
    cryptohash-sha256-0.11.102.0-1XGn2B7XIsy1t7F54UfgDi
    data-binary-ieee754-0.4.4-HlSlHq1qDaTKAKUZNW5rdz
    data-default-0.7.1.1-DVZWGRf90hqGebpGTaPvOV deepseq-1.4.4.0
    directory-1.3.6.0 dlist-1.0-KFY6kePYM7gDQLIElBL83C
    errors-2.3.0-1jMMqiGok7nGSgO7igf65q exceptions-0.10.4
    extra-1.7.9-HgDiAOSmyMbJkCAmsHf6J3 filepath-1.4.2.1 ghc-8.10.4
    ghc-boot-th-8.10.4 hashable-1.3.1.0-5wlJXyHm50SFuYmZaY4yzV
    haskell-src-meta-0.8.7-8rKLX0gUa2t2faOhdZZIEU
    hint-0.9.0.4-8kYDFr1aSp6FaF0mWeeVCW integer-gmp-1.0.3.0
    interpolate-0.2.1-1EN05UFEBY2HsxF947sK7S
    lens-4.19.2-5vk4uMRj9ksDVAJ2OGjSE4 mtl-2.2.2
    ordered-containers-0.2.2-GyU6swLq6k0DcCVw8rbPro
    parsers-0.12.10-LbgOlPbdHgfCNoFYXKRvUC
    pretty-show-1.10-EhdS2ToA2sEFyivshN51pj
    prettyprinter-1.7.0-KddZK4i0wCpEopqnOk43nb
    primitive-0.7.1.0-2kQMfgjKc9B2l3KIAcITNL process-1.6.9.0
    reducers-3.12.3-ENkWyIdMb7w2tiMZa9ZHcQ template-haskell-2.16.0.0
    temporary-1.3-Dp8CbxIkWfV8dZW5yXpuDt
    terminal-size-0.3.2.1-HihNy0RThZk4O1UkYpAxTd text-1.2.4.1
    text-show-3.9-7OHvBicfpF9AKGo5yidEN7 time-1.9.3
    transformers-0.5.6.2 trifecta-2.1.1-2GXJqx3Eums58IREHNzu90
    unordered-containers-0.2.13.0-8xrAhv2QGcsF4IHfxyp1m2
    utf8-string-1.0.2-IJwgsjBkJolJJdV6pKTYGC
    vector-0.12.2.0-Fhpcj4oaE8d6h7vKPBvHg3
    vector-binary-instances-0.2.5.1-9WmiGd2OCIR78VRUX7wV3t

haddock-interfaces:   /usr/share/doc/haskell-clash-lib/html/clash-lib.haddock
haddock-html:         /usr/share/doc/haskell-clash-lib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

